import { Schema as BootstrapSchema } from './schema';
import { Rule, Tree, chain, SchematicContext, branchAndMerge, noop } from '@angular-devkit/schematics';
import { NodePackageInstallTask } from '@angular-devkit/schematics/tasks';
import { addPackageToPackageJson } from './../utils/package';
import { addStyle, hasBootstrap } from './../utils/config';
import { FileSystemSchematicContext } from '@angular-devkit/schematics/tools';
// import {addModuleImportToRootModule} from './../utils/ast';

/*
const ngBootstrapVersion = '2.0.0-alpha.0';
function addNgBootstrapToPackageJson(): Rule {
  return (host: Tree) => {
    addPackageToPackageJson(host, 'dependencies', '@ng-bootstrap/ng-bootstrap', `^${ngBootstrapVersion}`);
    return host;
  };
}*
function addNgBootstrapModuleToAppModule(): Rule {
  return (host: Tree) => {
    addModuleImportToRootModule(host, 'NgbModule.forRoot()', '@ng-bootstrap/ng-bootstrap');
    return host;
  };
}*/

function addBootstrapToPackageJson(options: BootstrapSchema): Rule {
  return (host: Tree) => {
    addPackageToPackageJson(host, 'dependencies', 'bootstrap', `^${options.version}`);
    return host;
  };
}

function addBootstrapCSS(): Rule {
  return (host: Tree) => {
    addStyle(host, './node_modules/bootstrap/dist/css/bootstrap.css');
    return host;
  };
}

function installNodeDeps(): Rule {
  return (host: Tree, context: SchematicContext) => {
    context.addTask(new NodePackageInstallTask());
    return host;
  }
}

export function schematicsBootstrap(options: BootstrapSchema): Rule {
  return (host: Tree, context: FileSystemSchematicContext) => {
    if (!hasBootstrap(host)) {
      return chain([
        branchAndMerge(chain([
          addBootstrapToPackageJson(options),
          addBootstrapCSS(),
          installNodeDeps(),
        ])),
      ])(host, context);
    } else {
      noop();
    }
  };
}
